
import { useEffect, useState } from "react";
import { connect } from "react-redux";
import Header from "./components/header/Header";
import OrderIndex from "./components/order/OrderIndex"
import { fetchOrders } from "./actions/order_actions";


const App = ({ orders, fetchOrders }) => {

  const [ordersToShow, setOrdersToShow] = useState(orders);
  const [fetchAttempted, setFetchAttempted] = useState(false);

  useEffect(() => {
    if (!fetchAttempted) {
      setFetchAttempted(true);
      fetchOrders();
    }
  }, [fetchOrders, fetchAttempted]);

  return (
    <div className="app">
      <Header />
      <OrderIndex orders={ordersToShow} />
    </div>
  );
}

const mapStateToProps = (state) => ({
  orders: state.entities.orders,
});

const mapDispatchToProps = (dispatch) => ({
  fetchOrders: () => dispatch(fetchOrders()),
});

export default connect(mapStateToProps, mapDispatchToProps)(App);
